@@ -492,7 +492,7 @@ class ErrorPlot(PathPlot):
 
 class SpikesPlot(PathPlot, ColorbarPlot):
 
-    color_index = param.ClassSelector(default=1, allow_None=True,
+    color_index = param.ClassSelector(default=None, allow_None=True,
                                       class_=(basestring, int), doc="""
       Index of the dimension from which the color will the drawn""")
 
